# Formulario F.931

Para generar el txt para el Formulario 931 es necesario tener el archivo JSON con la información necesaria.

A continuación se muestra el modelo de JSON utilizado:

* [f931-info.json](/py_arg_reports/reporters/f931/samples/f931-info.json)

El resultado obtenido es un txt correspondiente al requerido por AFIP en la versión 42 de SICOSS

[Formato txt](/py_arg_reports/reporters/f931/samples/Formato_SICOSS_v42.pdf)

```python
import json

from py_arg_reports.reporters.f931.reporter import genera_txt_f931

my_json = 'py_arg_reports/reporters/f931/samples/f931-info.json
json_data = json.load(open(my_json, 'r'))

# Llamo a la función descargar_libro
resultado_descarga = genera_txt_f931(
    json_data=json_data,
    output_path='./downloads/',
)

Argumento "filename" es opcional
```

El archivo final estará disponible en `downloads/' con el nombre asignado